A package to simulate flows on a network
=========================================
Given a grapg $G(V, E)$, and a flowmodel that defines 
one (or mode) **fixed point(s)** f:E->R mapping each edge to a real number;
this module enables one to calculate the said fixed point. 
